@@ -1,19 +1,8 @@
-/* *************************************************************************
- *  Copyright 2015 Jakob Gruber <jakob.gruber@gmail.com>                   *
- *                                                                         *
- *  This program is free software: you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation, either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *  You should have received a copy of the GNU General Public License      *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.  *
- ************************************************************************* */
+/*
+    SPDX-FileCopyrightText: 2015 Jakob Gruber <jakob.gruber@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "selectboardwindow.h"
 
@@ -33,7 +22,7 @@ static QString diffString(const int difficulty);
 class LevelTableModel : public QAbstractTableModel
 {
 public:
-    LevelTableModel(QList<QSharedPointer<Level> > &levels, QObject * parent = 0);
+    LevelTableModel(QList<QSharedPointer<Level> > &levels, QObject * parent = nullptr);
 
     enum Columns {
         Name,
@@ -44,11 +33,11 @@ public:
         ColumnCount /* not a real column */
     };
 
-    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    int columnCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    QVariant data(const QModelIndex &index, int role) const Q_DECL_OVERRIDE;
-    QVariant headerData(int section, Qt::Orientation orientation, int role) const Q_DECL_OVERRIDE;
-    void sort(int column, Qt::SortOrder order = Qt::AscendingOrder) Q_DECL_OVERRIDE;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    int columnCount(const QModelIndex &parent = QModelIndex()) const override;
+    QVariant data(const QModelIndex &index, int role) const override;
+    QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
+    void sort(int column, Qt::SortOrder order = Qt::AscendingOrder) override;
 
 private:
     QList<QSharedPointer<Level> > &m_levels;
@@ -84,8 +73,8 @@ QVariant LevelTableModel::data(const QModelIndex &index, int role) const {
     case Name: return level->visibleName();
     case LevelSet: return level->levelset();
     case Difficulty: return diffString(level->difficulty());
-    case Size: return QString("%1x%2").arg(level->width()).arg(level->height());
-    case Solved: return (level->solved()) ? Time(level->solvedTime()).toString() : "-";
+    case Size: return QStringLiteral("%1x%2").arg(level->width()).arg(level->height());
+    case Solved: return (level->solved()) ? Time(level->solvedTime()).toString() : QStringLiteral("-");
     default: assert(0);
     }
 
@@ -155,7 +144,7 @@ void LevelTableModel::sort(int column, Qt::SortOrder order) {
     }
 
     std::stable_sort(m_levels.begin(), m_levels.end(), cmp);
-    emit dataChanged(index(0, 0), index(rowCount() - 1, columnCount() -1));
+    Q_EMIT dataChanged(index(0, 0), index(rowCount() - 1, columnCount() -1));
 }
 
 SelectBoardWindow::SelectBoardWindow(QWidget *parent)
@@ -276,7 +265,7 @@ void SelectBoardWindow::updateDetails(QSharedPointer<Level> level) {
         ui->labelImage->setPixmap(scaled);
     } else {
         ui->labelSolved->setText(i18nc("board not solved yet", "Solved: -"));
-        ui->labelImage->setText("?");
+        ui->labelImage->setText(QStringLiteral("?"));
     }
 }
 
